Skip to contents

This function extends officer::docx_dim() by also returning the body text dimensions within the margins, the aspect ratio of the page and body, and the page orientation as a string ("landscape" or "portrait").

Usage

dims_docx_ext(docx)

Arguments

docx

A rdocx object to get dimensions for.

Value

A list with page, landscape, margins, orientation, and body elements describing the page and body text dimensions.