This function extends officer::docx_dim() by also returning the body text
dimensions within the margins, the aspect ratio of the page and body, and the
page orientation as a string ("landscape" or "portrait").
Value
A list with page, landscape, margins, orientation, and
body elements describing the page and body text dimensions.