Preview a rdocx, rpptx, or rxlsx object in local default applications
Source:R/officer-utils.R
officer_open.Rdofficer_open() uses officer::open_file() to open a file ceated from a
rdocx, rpptx, or rxlsx object.
Arguments
- x
A rdocx, rpptx, or rxlsx object to save. Document properties won't be set for rxlsx objects.
- path
Optional. Set as temporary file with file extension matching type of input object
x.- ...
Arguments passed on to
write_officermodified_byIf the withr package is installed, modified_by overrides the default value for the lastModifiedBy property assigned to the output file by officer. Defaults to
Sys.getenv("USER")(the same value used by officer).
- overwrite
Defaults to
FALSE.- interactive
If
FALSE, warn the user and returnx.